# Creating coordinate systems

This documentation is a collection of functions used to create coordinate systems in `cryojax`'s conventions. The most important functions are `make_coordinate_grid` and `make_frequency_grid`.

::: cryojax.coordinates.make_coordinate_grid

::: cryojax.coordinates.make_frequency_grid

::: cryojax.coordinates.make_frequency_slice

::: cryojax.coordinates.make_1d_coordinate_grid

::: cryojax.coordinates.make_1d_frequency_grid
